@@ -4,7 +4,7 @@ from texbld.cli.validate import add_validate_args
 from texbld.cli.project import add_build_args, add_run_args
 
 from texbld.cli.scaffold import add_scaffold_args
-from texbld.common.exceptions import run_with_handlers
+from texbld.exceptions import run_with_handlers
 from texbld.config import VERSION
 
 parser = argparse.ArgumentParser(
@@ -22,7 +22,8 @@ add_run_args(subparsers.add_parser('run', aliases=['r'],
              help="Run a script in the corresponding TeXbld docker container"))
 add_validate_args(subparsers.add_parser(
     'validate', aliases=['v'], help="Run validations"))
-add_sha_args(subparsers.add_parser('getsha256', aliases=['sha'], help='Get the sha256 of a GitHub Image'))
+add_sha_args(subparsers.add_parser('getsha256', aliases=[
+             'sha'], help='Get the sha256 of a GitHub Image'))
 
 
 def execute(cli_args: 'list[str]'):
