@@ -35,8 +35,8 @@ def to_source_image(source: str) -> SourceImage:
         packages=config.get("packages", []),
         setup=config.get("setup", []),
         files=config.get("files", {}),
-        install=config.get("install", "apk add"),
-        update=config.get("update", "apk update"),
+        install=config.get("install", ""),
+        update=config.get("update", ""),
         inherit=to_inherit(config.get("inherit")),
         project_files=config.get("project", {}).get("files", {}),
         project_commands=config.get("project", {}).get("commands", {}),
