@@ -1,5 +1,4 @@
 import os
-import shutil
 from texbld.common.image import Image
 from texbld.config import PROJECT_CONFIG_FILE
 from texbld.scaffold.copy import copy_image
@@ -29,9 +28,8 @@ def scaffold_image(directory: str):
     name = os.path.basename(directory)
     if os.path.exists(directory):
         raise FileExistsError(directory)
-    os.makedirs(os.path.dirname(directory), exist_ok=True)
-    src = os.path.join(os.path.dirname(__file__), "sample_image")
-    shutil.copytree(src, directory)
-    text = open(os.path.join(directory, "image.toml")).read()
+    os.makedirs(directory)
+    src_path = os.path.join(os.path.dirname(__file__), "sample_image.toml")
+    text = open(src_path).read()
     open(os.path.join(directory, "image.toml"), "w").write(
         text.replace("image_name", name))
